Package: BEclear
Type: Package
Title: Correction of batch effects in DNA methylation data
Version: 2.26.0
Date: 2023-04-06
Authors@R: c(person("Livia", "Rasp", email = "livia.rasp@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-0164-2163")),
             person("Markus", "Merl", role = "aut"),
             person("Ruslan", "Akulenko", role = "aut"))
Description: Provides functions to detect and correct for batch effects in
             DNA methylation data. The core function  is based on latent factor
             models and can also be used to predict missing values in any other 
             matrix containing real numbers.
License: GPL-3
SystemRequirements: C++11
Depends: BiocParallel (>= 1.14.2)
Imports: futile.logger, Rdpack, Matrix, data.table (>= 1.11.8), Rcpp,
        abind, stats, graphics, utils, methods, dixonTest, ids
Suggests: testthat, BiocStyle, knitr, rmarkdown, pander, seewave
VignetteBuilder: knitr
biocViews: BatchEffect, DNAMethylation, Software, Preprocessing,
        StatisticalMethod
RoxygenNote: 7.2.2
RdMacros: Rdpack
Encoding: UTF-8
URL: https://github.com/uds-helms/BEclear
BugReports: https://github.com/uds-helms/BEclear/issues
LinkingTo: Rcpp
git_url: https://git.bioconductor.org/packages/BEclear
git_branch: RELEASE_3_22
git_last_commit: 575a6df
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 02:43:04 UTC; biocbuild
Author: Livia Rasp [aut, cre] (ORCID: <https://orcid.org/0000-0003-0164-2163>),
  Markus Merl [aut],
  Ruslan Akulenko [aut]
Maintainer: Livia Rasp <livia.rasp@gmail.com>
