# Generated by roxygen2: do not edit by hand

export(calcBatchEffects)
export(calcScore)
export(calcSummary)
export(clearBEgenes)
export(correctBatchEffect)
export(countValuesToPredict)
export(findOutsideValues)
export(imputeMissingData)
export(localLoss)
export(loss)
export(makeBoxplot)
export(preprocessBEclear)
export(replaceOutsideValues)
import(BiocParallel)
import(Matrix)
import(Rcpp)
import(Rdpack)
import(data.table)
import(futile.logger)
importFrom(Matrix,norm)
importFrom(Rdpack,reprompt)
importFrom(abind,abind)
importFrom(dixonTest,dixonTest)
importFrom(futile.logger,flog.info)
importFrom(graphics,boxplot)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(ids,random_id)
importFrom(methods,as)
importFrom(methods,is)
importFrom(stats,ks.test)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,rnorm)
importFrom(utils,write.table)
useDynLib(BEclear)
