# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Calculating the Local Loss
#' 
#' @keywords internal
#' 
#' @description Calculates the gradient dR and dL for the current epoch.
#' 
#' @return a list containing two matrices containing the local loss
#'
#' @import Rcpp
#' @export localLoss
localLoss <- function(L, R, is, js, error_matrix) {
    .Call('_BEclear_localLoss', PACKAGE = 'BEclear', L, R, is, js, error_matrix)
}

